==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftControllerManagerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenShiftControllerManagerListBuilder extends io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList,io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListBuilder>{
  public OpenShiftControllerManagerListBuilder() {
    this(false);
  }
  public OpenShiftControllerManagerListBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenShiftControllerManagerList(), validationEnabled);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenShiftControllerManagerList(), validationEnabled);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance) {
    this(fluent, instance, false);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance) {
    this(instance,false);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList build() {
    OpenShiftControllerManagerList buildable = new OpenShiftControllerManagerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftControllerManagerListBuilder that = (OpenShiftControllerManagerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftControllerManagerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenShiftControllerManagerListBuilder extends io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList,io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListBuilder>{
  public OpenShiftControllerManagerListBuilder() {
    this(false);
  }
  public OpenShiftControllerManagerListBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenShiftControllerManagerList(), validationEnabled);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenShiftControllerManagerList(), validationEnabled);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance) {
    this(fluent, instance, false);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance) {
    this(instance,false);
  }
  public OpenShiftControllerManagerListBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerList build() {
    OpenShiftControllerManagerList buildable = new OpenShiftControllerManagerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftControllerManagerListBuilder that = (OpenShiftControllerManagerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
